
if (CMAKE_VERSION VERSION_LESS 2.8.3)
    message(FATAL_ERROR "Qt 5 requires at least CMake version 2.8.3")
endif()

set(_qt5AccountsService_install_prefix "/usr/lib/qt5")

# For backwards compatibility only. Use Qt5AccountsService_VERSION instead.
set(Qt5AccountsService_VERSION_STRING 0.1.0)

set(Qt5AccountsService_LIBRARIES Qt5::AccountsService)

macro(_qt5_AccountsService_check_file_exists file)
    if(NOT EXISTS "${file}" )
        message(FATAL_ERROR "The imported target \"Qt5::AccountsService\" references the file
   \"${file}\"
but this file does not exist.  Possible reasons include:
* The file was deleted, renamed, or moved to another location.
* An install or uninstall procedure did not complete successfully.
* The installation package was faulty and contained
   \"${CMAKE_CURRENT_LIST_FILE}\"
but not all the files it references.
")
    endif()
endmacro()


macro(_populate_AccountsService_target_properties Configuration LIB_LOCATION IMPLIB_LOCATION)
    set_property(TARGET Qt5::AccountsService APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

    set(imported_location "/usr/lib/${LIB_LOCATION}")
    _qt5_AccountsService_check_file_exists(${imported_location})
    set_target_properties(Qt5::AccountsService PROPERTIES
        "IMPORTED_LINK_INTERFACE_LIBRARIES_${Configuration}" "${_Qt5AccountsService_LIB_DEPENDENCIES}"
        "IMPORTED_LOCATION_${Configuration}" ${imported_location}
        "IMPORTED_SONAME_${Configuration}" "libQt0AccountsService.so.0"
    )

endmacro()

if (NOT TARGET Qt5::AccountsService)

    set(_Qt5AccountsService_OWN_INCLUDE_DIRS "/usr/include/qt5/" "/usr/include/qt5/QtAccountsService")
    set(Qt5AccountsService_PRIVATE_INCLUDE_DIRS
        "/usr/include/qt5/QtAccountsService/0.1.0"
        "/usr/include/qt5/QtAccountsService/0.1.0/QtAccountsService"
    )

    foreach(_dir ${_Qt5AccountsService_OWN_INCLUDE_DIRS})
        _qt5_AccountsService_check_file_exists(${_dir})
    endforeach()

    # Only check existence of private includes if the Private component is
    # specified.
    list(FIND Qt5AccountsService_FIND_COMPONENTS Private _check_private)
    if (NOT _check_private STREQUAL -1)
        foreach(_dir ${Qt5AccountsService_PRIVATE_INCLUDE_DIRS})
            _qt5_AccountsService_check_file_exists(${_dir})
        endforeach()
    endif()

    set(Qt5AccountsService_INCLUDE_DIRS ${_Qt5AccountsService_OWN_INCLUDE_DIRS})

    set(Qt5AccountsService_DEFINITIONS -DQT_ACCOUNTSSERVICE_LIB)
    set(Qt5AccountsService_COMPILE_DEFINITIONS QT_ACCOUNTSSERVICE_LIB)

    set(_Qt5AccountsService_MODULE_DEPENDENCIES "DBus;Gui;Core")

    set(_Qt5AccountsService_FIND_DEPENDENCIES_REQUIRED)
    if (Qt5AccountsService_FIND_REQUIRED)
        set(_Qt5AccountsService_FIND_DEPENDENCIES_REQUIRED REQUIRED)
    endif()
    set(_Qt5AccountsService_FIND_DEPENDENCIES_QUIET)
    if (Qt5AccountsService_FIND_QUIETLY)
        set(_Qt5AccountsService_DEPENDENCIES_FIND_QUIET QUIET)
    endif()
    set(_Qt5AccountsService_FIND_VERSION_EXACT)
    if (Qt5AccountsService_FIND_VERSION_EXACT)
        set(_Qt5AccountsService_FIND_VERSION_EXACT EXACT)
    endif()

    foreach(_module_dep ${_Qt5AccountsService_MODULE_DEPENDENCIES})
        if (NOT Qt5${_module_dep}_FOUND)
            find_package(Qt5${_module_dep}
                0.1.0 ${_Qt5AccountsService_FIND_VERSION_EXACT}
                ${_Qt5AccountsService_DEPENDENCIES_FIND_QUIET}
                ${_Qt5AccountsService_FIND_DEPENDENCIES_REQUIRED}
                PATHS "${CMAKE_CURRENT_LIST_DIR}/.." NO_DEFAULT_PATH
            )
        endif()

        if (NOT Qt5${_module_dep}_FOUND)
            set(Qt5AccountsService_FOUND False)
            return()
        endif()

        list(APPEND Qt5AccountsService_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
        list(APPEND Qt5AccountsService_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
        list(APPEND Qt5AccountsService_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
        list(APPEND Qt5AccountsService_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
        list(APPEND Qt5AccountsService_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
    endforeach()
    list(REMOVE_DUPLICATES Qt5AccountsService_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5AccountsService_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5AccountsService_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5AccountsService_COMPILE_DEFINITIONS)
    if (Qt5AccountsService_EXECUTABLE_COMPILE_FLAGS)
        list(REMOVE_DUPLICATES Qt5AccountsService_EXECUTABLE_COMPILE_FLAGS)
    endif()

    set(_Qt5AccountsService_LIB_DEPENDENCIES "Qt5::DBus;Qt5::Gui;Qt5::Core")

    add_library(Qt5::AccountsService SHARED IMPORTED)

    set_property(TARGET Qt5::AccountsService PROPERTY
      INTERFACE_INCLUDE_DIRECTORIES ${_Qt5AccountsService_OWN_INCLUDE_DIRS})
    set_property(TARGET Qt5::AccountsService PROPERTY
      INTERFACE_COMPILE_DEFINITIONS QT_ACCOUNTSSERVICE_LIB)

    _populate_AccountsService_target_properties(RELEASE "libQt0AccountsService.so.0.1.0" "" )






_qt5_AccountsService_check_file_exists("${CMAKE_CURRENT_LIST_DIR}/Qt5AccountsServiceConfigVersion.cmake")

endif()
